#!/bin/bash

###############################################################
#Copyright  2023 Quick Heal Technologies (P) Ltd.

#Module Name:
#updcustcertificate.sh

#Abstract:
#This script replace original certificate with custom certificate

#Revision History:
#Date:	June 30 2023.
#Author:	Pratima Shelar.
###############################################################

RED='\033[0;31m'
GREEN='\033[0;32m' 
NOCOLOR='\033[0m'
# Make sure only root can run our script
if [ "$(id -u)" != "0" ]; then
   echo -e "\n ${RED} This script must be run as root user ${NOCOLOR}"
   exit 1
fi

#get custom certificate location
read -e -p "Please enter the custom certificate .crt file path along with name (without spaces),for eg:- /test/selfsigned.crt : " CPTH
echo $CPTH

if [ -z "$CPTH" ]
then
   echo -e "\n ${RED} The certificate filename is empty, Please retry with correct .crt file  ${NOCOLOR}"
   exit 1
fi

if [ ! -f $CPTH ]
then
    echo -e "\n ${RED} $CPTH does not exist, Please retry with correct path ${NOCOLOR} \n"
    exit 1
fi

if [[ "$CPTH" =~ \ |\' ]]; then
   echo -e "\n ${RED} The certificate filename cannot contain spaces, Please retry with correct .crt file  ${NOCOLOR}"
   exit 1
fi

read -e -p "Please enter the custom certificate .key file path along with name (without spaces),for eg:- /test/selfsigned.key : " KPTH
echo $KPTH

if [ -z "$KPTH" ]
then
   echo -e "\n ${RED} The certificate filename is empty, Please retry with correct .key file  ${NOCOLOR}"
   exit 1
fi

if [ ! -f $KPTH ]
then
    echo -e "\n ${RED} $KPTH does not exist, Please retry with correct path ${NOCOLOR} \n"
    exit 1
fi

if [[ "$KPTH" =~ \ |\' ]]; then
   echo -e "\n ${RED} The certificate filename cannot contain spaces, Please retry with correct .key file  ${NOCOLOR}"
   exit 1
fi

Crtfilename=$(basename $CPTH)
Keyfilename=$(basename $KPTH) 

if [ -f "/etc/nginx/certs/"$Crtfilename ]
  then
    sed '' '/etc/nginx/certs/'$Crtfilename -i.bak
fi

if [ -f "/etc/nginx/private/"$Keyfilename ]
  then
    sed '' '/etc/nginx/private/'$Keyfilename -i.bak
fi

cp $CPTH /etc/nginx/certs

if [ $? -ne 0 ]; then
   echo -e "\n ${RED} Failed to copy .crt file, Please retry again  ${NOCOLOR}"
   exit 1
fi

cp $KPTH /etc/nginx/private/

if [ $? -ne 0 ]; then
   echo -e "\n ${RED} Failed to copy .key file, Please retry again  ${NOCOLOR}"
   exit 1
fi

sed '' /etc/nginx/nginx.conf -i.bak

#update nginx.conf file 
sed -ri "s~(ssl_certificate) .*$~\1 /etc/nginx/certs/"$Crtfilename";~;s~(ssl_certificate_key) .*$~\1 /etc/nginx/private/"$Keyfilename";~" /etc/nginx/nginx.conf


if out=$(nginx -t 2>&1) 
  then
   rm /etc/nginx/nginx.conf.bak
   echo -e "\n ${GREEN} Custom certificate installed successfully! ${NOCOLOR} \n"
else
   mv /etc/nginx/nginx.conf.bak /etc/nginx/nginx.conf
   echo -e "\n ${RED} Failed to install Custom certificate, Please retry again ${NOCOLOR} \n"
fi

nginx -s reload 
